"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
const SHARED_TRANSACTION_ID = Symbol('SHARED_TRANSACTION_ID');
const inlineLedgerExecuteStatement = Object.assign(async (pool, sql, transactionId = null, passthroughRuntimeErrors = false) => {
  const {
    PassthroughError,
    rdsDataService,
    dbClusterOrInstanceArn,
    awsSecretStoreArn,
    coercer,
    sharedTransactionId
  } = pool;

  for (;;) {
    try {
      const transactionScope = transactionId != null ? transactionId.constructor === String ? {
        transactionId
      } : transactionId === SHARED_TRANSACTION_ID ? sharedTransactionId != null ? {
        transactionId: sharedTransactionId
      } : {} : (() => {
        throw new Error('Invalid transactionId');
      })() : {};
      const result = await rdsDataService.executeStatement({
        resourceArn: dbClusterOrInstanceArn,
        secretArn: awsSecretStoreArn,
        database: 'postgres',
        continueAfterTimeout: false,
        includeResultMetadata: true,
        ...transactionScope,
        sql
      });
      const {
        columnMetadata,
        records
      } = result;

      if (!Array.isArray(records) || columnMetadata == null) {
        return [];
      }

      const rows = [];

      for (const record of records) {
        const row = {};

        for (let i = 0; i < columnMetadata.length; i++) {
          const columnName = columnMetadata[i].name;

          if (columnName != null) {
            row[columnName] = coercer(record[i]);
          }
        }

        rows.push(row);
      }

      return rows;
    } catch (error) {
      if (pool.activePassthrough) {
        if (PassthroughError.isPassthroughError(error, !!passthroughRuntimeErrors)) {
          throw new PassthroughError(transactionId != null && transactionId.constructor === String ? transactionId : null);
        }

        throw error;
      } else {
        if (PassthroughError.isPassthroughError(error, false)) {
          await new Promise(resolve => setTimeout(resolve, 100));
        } else {
          throw error;
        }
      }
    }
  }
}, {
  SHARED_TRANSACTION_ID
});
var _default = inlineLedgerExecuteStatement;
exports.default = _default;
//# sourceMappingURL=inline-ledger-execute-statement.js.map