"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
const compareOperators = {
  $eq: (a, b) => `
    (((${a} = ${b}) and (not (${a} is null)) and (not (${b} is null))) or      
    ((${a} is null) and (${b} is null)))
  `,
  $ne: (a, b) => `
    (((${a} <> ${b}) and (not (${a} is null)) and (not (${b} is null))) or      
    ((${a} is null) and (not (${b} is null)) ) or                           
    ((${b} is null) and (not (${a} is null)) ))
  `,
  $lte: (a, b) => `
    (((${a} <= ${b}) and (not (${a} is null)) and (not (${b} is null))) or
    ((${a} is null) and (${b} is null)))
  `,
  $gte: (a, b) => `
    (((${a} >= ${b}) and (not (${a} is null)) and (not (${b} is null))) or
    ((${a} is null) and (${b} is null)))
  `,
  $lt: (a, b) => `
    (((${a} < ${b}) and (not (${a} is null)) and (not (${b} is null))))
  `,
  $gt: (a, b) => `
    (((${a} > ${b}) and (not (${a} is null)) and (not (${b} is null))))
  `
};

const searchToWhereExpression = (expression, escapeId, escapeStr, makeNestedPath) => {
  const searchExprArray = [];
  const isDocumentExpr = !('$and' in expression || '$or' in expression || '$not' in expression);

  if (isDocumentExpr) {
    for (let fieldName of Object.keys(expression)) {
      const [baseName, ...nestedPath] = fieldName.split('.');
      const resultFieldName = nestedPath.length > 0 ? `${escapeId(baseName)} #> '${makeNestedPath(nestedPath)}'` : escapeId(baseName);
      let fieldValue = expression[fieldName];
      let fieldOperator = '$eq';

      if (fieldValue instanceof Object) {
        fieldOperator = Object.keys(fieldValue)[0];
        fieldValue = fieldValue[fieldOperator];
      }

      const compareInlinedValue = fieldValue != null ? `CAST(${escapeStr(JSON.stringify(fieldValue))} AS JSONB)` : `CAST(${escapeStr('null')} AS JSONB)`;
      const resultExpression = compareOperators[fieldOperator](resultFieldName, compareInlinedValue);
      searchExprArray.push(resultExpression);
    }

    return searchExprArray.join(' AND ');
  }

  for (let operatorName of Object.keys(expression)) {
    if (operatorName === '$and' || operatorName === '$or') {
      const localSearchExprArray = [];

      for (let innerExpr of expression[operatorName]) {
        const whereExpr = searchToWhereExpression(innerExpr, escapeId, escapeStr, makeNestedPath);
        localSearchExprArray.push(whereExpr);
      }

      const joiner = operatorName === '$and' ? ' AND ' : ' OR ';

      if (localSearchExprArray.length > 1) {
        searchExprArray.push(localSearchExprArray.map(val => `(${val})`).join(joiner));
      } else {
        searchExprArray.push(localSearchExprArray[0]);
      }

      break;
    }

    if (operatorName === '$not') {
      const whereExpr = searchToWhereExpression(expression[operatorName], escapeId, escapeStr, makeNestedPath);
      searchExprArray.push(`NOT (${whereExpr})`);
      break;
    }
  }

  return searchExprArray.join(' AND ');
};

var _default = searchToWhereExpression;
exports.default = _default;
//# sourceMappingURL=search-to-where-expression.js.map